@@ -409,7 +409,7 @@ generate_pca_plots <- function(ns, input, output, dataSelection, classSelection,
       if (ncol(classSelection$data) == 3){
         colors = getGroupColors(classSelection$data)
         plotIndiv(result(), classes = classSelection$data[,2], title = paste("PCA on", dataSelection$data$name ,"data"), legend.title = legend.title, 
-                  comp = comp.indiv(), indNames = input$indiv.names, col.per.group = colors)
+                  comp = comp.indiv(), indNames = input$indiv.names, col = colors)
       } else {
         plotIndiv(result(), classes = classSelection$data[,2], title = paste("PCA on", dataSelection$data$name ,"data"), legend.title = legend.title, 
                   comp = comp.indiv(), indNames = input$indiv.names)
@@ -426,7 +426,12 @@ generate_pca_plots <- function(ns, input, output, dataSelection, classSelection,
   plot.load <- function(){
     if(!is.null(result())){
       req(input$load.comp)
-      plotLoadings(result(), as.numeric(input$load.comp))
+      req(input$load.ndisplay)
+      if (input$load.ndisplay == "All"){
+        plotLoadings(result(), as.numeric(input$load.comp))
+      } else {
+        plotLoadings(result(), as.numeric(input$load.comp), ndisplay = as.numeric(input$load.ndisplay))
+      }
     }
   }
   
@@ -450,7 +455,7 @@ generate_pca_plots <- function(ns, input, output, dataSelection, classSelection,
         colors = getGroupColors(classSelection$data)
         plotIndiv(resultTuned(), classes = classSelection$data[,2], title = paste("PCA on", dataSelection$data$name ,"data"), 
                   legend.title = legend.title, comp = comp.indiv.tuned(), 
-                  indNames = input$indiv.names.tuned, col.per.group = colors)
+                  indNames = input$indiv.names.tuned, col = colors)
       } else {
         plotIndiv(resultTuned(), classes = classSelection$data[,2], title = paste("PCA on", dataSelection$data$name ,"data"), 
                   legend.title = legend.title, comp = comp.indiv.tuned(), 
@@ -468,7 +473,13 @@ generate_pca_plots <- function(ns, input, output, dataSelection, classSelection,
   plot.load.tuned <- function(){
     if(!is.null(resultTuned())){
       req(input$load.comp.tuned)
-      plotLoadings(resultTuned(), as.numeric(input$load.comp.tuned))
+      req(input$load.ndisplay.tuned)
+      if (input$load.ndisplay.tuned == "All"){
+        plotLoadings(resultTuned(), as.numeric(input$load.comp.tuned))
+      } else {
+        plotLoadings(resultTuned(), as.numeric(input$load.comp.tuned),
+                     ndisplay = as.numeric(input$load.ndisplay.tuned))
+      }
     }
   }
   
@@ -553,12 +564,14 @@ generate_pca_plots <- function(ns, input, output, dataSelection, classSelection,
   output$Scree.download <- getDownloadHandler("PCA_Screeplot.png", plot.scree)
   output$Var.download <- getDownloadHandler("PCA_CorrelationCircleplot.png", plot.var)
   output$Load.download <- getDownloadHandler("PCA_Loadingsplot.png", plot.load, width = 2592, height = 1944)
+  output$Load.table.download <- getDownloadHandler("PCA_Loadingsplot.csv", contentfct = plot.load, type = "csv")
   output$SelVar.download <- getDownloadHandler("PCA_SelectedFeatures.csv", table.selVar, type = "csv")
   
   output$Indiv.download.tuned <- getDownloadHandler("PCA_reduced_Sampleplot.png", plot.indiv.tuned)
   output$Scree.download.tuned <- getDownloadHandler("PCA_reduced_Screeplot.png", plot.scree.tuned)
   output$Var.download.tuned <- getDownloadHandler("PCA_reduced_CorrelationCircleplot.png", plot.var.tuned)
   output$Load.download.tuned <- getDownloadHandler("PCA_reduced_Loadingsplot.png", plot.load.tuned, width = 2592, height = 1944)
+  output$Load.table.download.tuned <- getDownloadHandler("PCA_reduced_Loadingsplot.csv", contentfct = plot.load.tuned, type = "csv")
   output$SelVar.download.tuned <- getDownloadHandler("PCA_reduced_SelectedFeatures.csv", table.selVar.tuned, type = "csv")
   
   output$Filter.download <- downloadHandler(
@@ -582,7 +595,7 @@ render_pca_infotexts <- function(output){
       It works unsupervised and determines uncorrelated and orthogonal principal components (PC) in the data.
       Therefore, the PCA only works with the data matrix containing the samples and features information without knowing the classification of the samples.
       It helps to identify characteristics of the data and eventual biases and artefacts by visualising the PCs with the respective features and samples. <br/>
-      Additional information can be found on the <a class='mixOmics-link' href='http://mixomics.org/methods/spca/' target='_blank'>mixOmics website</a> and
+      Additional information can be found on the <a class='mixOmics-link' href='https://mixomics.org/methods/spca/' target='_blank'>mixOmics website</a> and
       in several scientific papers (e.g. <a class='ref-link' href='https://link.springer.com/article/10.1186/1471-2105-13-24' target='_blank'>Yao et.al. (2012)</a>).
       More information about the plots and the feature selection and tuning methods can be found on our <a class='mixOmics-link' onclick=\"document.getElementById('tab-help-plots').click();\">'Plots-Helppage'</a> and
       <a class='mixOmics-link' onclick=\"document.getElementById('tab-help-tuning').click();\">'Feature selection and tuning-Helppage'</a>.</br>
